@@ -68,7 +68,7 @@ case $AUTOMAKE_STRING in
     echo "*** KDE requires automake $required_automake_version"
     exit 1
     ;;
-  automake*1.6.* | automake*1.7* | automake*1.8* | automake*1.9*)
+  automake*1.6.* | automake*1.7* | automake*1.8* | automake*1.9* | automake*1.10*)
     echo "*** $AUTOMAKE_STRING found."
     UNSERMAKE=no
     ;;
@@ -307,6 +307,9 @@ if test -f configure.in.in; then
       if test -n "$line"; then
 	  modulename=`echo $line | sed -e "s#AM_INIT_AUTOMAKE(\([^,]*\),.*#\1#"`
 	  VERSION=`echo $line | sed -e "s#AM_INIT_AUTOMAKE([^,]*, *\([^)]*\)).*#\1#"`
+        if test -z "$KMYMONEY_RELEASE"; then
+            VERSION="$VERSION-CVS";
+        fi
       fi
       sed -e "s#AM_INIT_AUTOMAKE([^@].*#dnl PACKAGE set before#" \
           configure.in.new > configure.in && mv configure.in configure.in.new
