@@ -20,8 +20,6 @@ email                : mte@users.sourceforge.net
  *                                                                         *
  ***************************************************************************/
 
-#include <stdarg.h>
-
 // ----------------------------------------------------------------------------
 // QT Includes
 #include <qfile.h>
@@ -83,6 +81,7 @@ void MyMoneyGncReader::setOptions () {
     // set users input options
     m_dropSuspectSchedules = dlg.scheduleOption();
     m_investmentOption = dlg.investmentOption();
+//    m_useFinanceQuote = dlg.quoteOption(); not implemented in 0.8
     m_decoder = dlg.decodeOption();
     gncdebug = dlg.generalDebugOption();
     xmldebug = dlg.xmlDebugOption();
@@ -110,35 +109,17 @@ GncObject::GncObject () {
 }
 
 // Check that the current element is of a version we are coded for
-void GncObject::checkVersion (const QString& elName, const QXmlAttributes& elAttrs) {
-#ifdef _GNCFILEANON // suppress all checks
-    static bool validHeaderFound = true;
-    return;
-#else
-  // a list of elements to check, and the required version numbers
-  static const QString versionList[] = {"gnc:book 2.0.0", "gnc:commodity 2.0.0", "gnc:pricedb 1",
-                                        "gnc:account 2.0.0", "gnc:transaction 2.0.0", "gnc:schedxaction 1.0.0",
-                                        "gnc:freqspec 1.0.0", "zzz" // zzz = stopper
-                                       };
-  static bool validHeaderFound = false;
+void GncObject::checkVersion (const QString& elName, const QXmlAttributes& elAttrs, const map_elementVersions& map) {
   TRY
-  if (!validHeaderFound) {  // check the header first
-    if (elName != "gnc-v2") throw new MYMONEYEXCEPTION (i18n("Invalid header for file. Should be gnc-v2"));
-  }
-  validHeaderFound = true;
-
-  for (uint i = 0; versionList[i] != "zzz"; i++) {
-    if (versionList[i].section (' ', 0, 0) == elName) {
-      if (elAttrs.value("version") != versionList[i].section(' ', 1, 1)) {
-          QString em = i18n("chkVersion: Element %1 must have version %2")
-                          .arg(elName).arg(versionList[i].section(' ', 1, 1));
-        throw new MYMONEYEXCEPTION (em);
-      }
+  if (map.contains(elName)) { // if it's not in the map, there's nothing to check
+    if (!map[elName].contains(elAttrs.value("version"))) {
+      QString em = i18n("checkVersion: Sorry. This importer cannot handle version %1 of element %2")
+                          .arg(elAttrs.value("version")).arg(elName);
+      throw new MYMONEYEXCEPTION (em);
     }
   }
   return ;
   PASS
-#endif // _GNCFILEANON
 }
 
 // Check if this element is in the current object's sub element list
@@ -687,19 +668,21 @@ void GncTemplateSplit::endSubEl(GncObject *subObj) {
 //************* GncSchedule********************************************
 GncSchedule::GncSchedule () {
   m_subElementListCount = END_Schedule_SELS;
-  static const QString subEls[] = {"sx:start", "sx:last", "sx:end", "gnc:freqspec", "sx:deferredInstance"};
+  static const QString subEls[] = {"sx:start", "sx:last", "sx:end", "gnc:freqspec", "gnc:recurrence","sx:deferredInstance"};
   m_subElementList = subEls;
   m_dataElementListCount = END_Schedule_DELS;
-  static const QString dataEls[] = {"sx:name", "sx:autoCreate", "sx:autoCreateNotify",
+  static const QString dataEls[] = {"sx:name", "sx:enabled", "sx:autoCreate", "sx:autoCreateNotify",
                                     "sx:autoCreateDays", "sx:advanceCreateDays", "sx:advanceRemindDays",
                                     "sx:instanceCount", "sx:num-occur",
                                     "sx:rem-occur", "sx:templ-acct"};
   m_dataElementList = dataEls;
-  static const unsigned int anonClasses[] = {NXTSCHD, ASIS, ASIS, ASIS, ASIS, ASIS, ASIS, ASIS, ASIS, ASIS};
+  static const unsigned int anonClasses[] = {NXTSCHD, ASIS, ASIS, ASIS, ASIS, ASIS, ASIS, ASIS, ASIS, ASIS, ASIS};
   m_anonClassList = anonClasses;
   for (uint i = 0; i < m_dataElementListCount; i++) m_v.append (new QString (""));
   m_vpStartDate = m_vpLastDate = m_vpEndDate = NULL;
   m_vpFreqSpec = NULL;
+  m_vpRecurrence.clear();
+  m_vpRecurrence.setAutoDelete(true);
   m_vpSchedDef = NULL;
 }
 
@@ -716,6 +699,7 @@ GncObject *GncSchedule::startSubEl() {
   case LASTDATE:
   case ENDDATE: next = new GncDate; break;
   case FREQ: next = new GncFreqSpec; break;
+  case RECURRENCE: next = new GncRecurrence; break;
   case DEFINST: next = new GncSchedDef; break;
   default: throw new MYMONEYEXCEPTION ("GncSchedule rcvd invalid m_state");
   }
@@ -730,6 +714,7 @@ void GncSchedule::endSubEl(GncObject *subObj) {
   case LASTDATE: m_vpLastDate = static_cast<GncDate *>(subObj); break;
   case ENDDATE: m_vpEndDate = static_cast<GncDate *>(subObj); break;
   case FREQ: m_vpFreqSpec = static_cast<GncFreqSpec *>(subObj); break;
+  case RECURRENCE: m_vpRecurrence.append(static_cast<GncRecurrence *>(subObj)); break;
   case DEFINST: m_vpSchedDef = static_cast<GncSchedDef *>(subObj); break;
   }
   return ;
@@ -784,6 +769,71 @@ void GncFreqSpec::terminate() {
   pMain->convertFreqSpec (this);
   return ;
 }
+//************* GncRecurrence********************************************
+GncRecurrence::GncRecurrence () {
+  m_subElementListCount = END_Recurrence_SELS;
+  static const QString subEls[] = {"recurrence:start"};
+  m_subElementList = subEls;
+  m_dataElementListCount = END_Recurrence_DELS;
+  static const QString dataEls[] = {"recurrence:mult", "recurrence:period_type"};
+  m_dataElementList = dataEls;
+  static const unsigned int anonClasses[] = {ASIS, ASIS};
+  m_anonClassList = anonClasses;
+  for (uint i = 0; i < m_dataElementListCount; i++) m_v.append (new QString (""));
+}
+
+GncRecurrence::~GncRecurrence () {
+  delete m_vpStartDate;
+}
+
+GncObject *GncRecurrence::startSubEl() {
+  TRY
+  if (pMain->xmldebug) qDebug ("Recurrence start subel m_state %d", m_state);
+
+  GncObject *next = 0;
+  switch (m_state) {
+  case STARTDATE: next = new GncDate; break;
+  default: throw new MYMONEYEXCEPTION ("GncRecurrence rcvd invalid m_state");
+  }
+  return (next);
+  PASS
+}
+
+void GncRecurrence::endSubEl(GncObject *subObj) {
+  if (pMain->xmldebug) qDebug ("Recurrence end subel");
+  switch (m_state) {
+  case STARTDATE: m_vpStartDate = static_cast<GncDate *>(subObj); break;
+  }
+  m_dataPtr = 0;
+  return ;
+}
+
+void GncRecurrence::terminate() {
+  pMain->convertRecurrence (this);
+  return ;
+}
+
+const QString GncRecurrence::getFrequency() const {
+  // This function converts a gnucash 2.2 recurrence specification into it's previous equivalent
+  // This will all need re-writing when MTE finishes the schedule re-write
+  if (periodType() == "once") return("once");
+  if ((periodType() == "day") and (mult() == "1")) return("daily");
+  if (periodType() == "week") {
+    if (mult() == "1") return ("weekly");
+    if (mult() == "2") return ("bi_weekly");
+    if (mult() == "4") return ("four-weekly");
+  }
+  if (periodType() == "month") {
+    if (mult() == "1") return ("monthly");
+    if (mult() == "2") return ("two-monthly");
+    if (mult() == "3") return ("quarterly");
+    if (mult() == "4") return ("tri_annually");
+    if (mult() == "6") return ("semi_yearly");
+    if (mult() == "12") return ("yearly");
+    if (mult() == "24") return ("two-yearly");
+  }
+  return ("unknown");
+}
 
 //************* GncSchedDef********************************************
 GncSchedDef::GncSchedDef () {
@@ -816,6 +866,7 @@ bool XmlReader::startDocument() {
   m_co = new GncFile; // create initial object, push to stack , pass it the 'main' pointer
   m_os.push (m_co);
   m_co->setPm (pMain);
+  m_headerFound = false;
 #ifdef _GNCFILEANON
   pMain->oStream << "<?xml version=\"1.0\"?>";
   lastType = -1;
@@ -840,17 +891,22 @@ bool XmlReader::startElement (const QString&, const QString&, const QString& elN
     }
     pMain->oStream << '<' << elName;
     for (i = 0; i < elAttrs.count(); i++) {
-          pMain->oStream << ' ' << elAttrs.qName(i) << '='  << '"' << elAttrs.value(i) << '"';
+      pMain->oStream << ' ' << elAttrs.qName(i) << '='  << '"' << elAttrs.value(i) << '"';
     }
     pMain->oStream << '>';
     lastType = 0;
+#else
+    if ((!m_headerFound) && (elName != "gnc-v2"))
+      throw new MYMONEYEXCEPTION (i18n("Invalid header for file. Should be 'gnc-v2'"));
+    m_headerFound = true;
 #endif // _GNCFILEANON
-    GncObject::checkVersion (elName, elAttrs);
+    m_co->checkVersion (elName, elAttrs, pMain->m_versionList);
     // check if this is a sub object element; if so, push stack and initialize
     GncObject *temp = m_co->isSubElement (elName, elAttrs);
     if (temp != 0) {
       m_os.push (temp);
       m_co = m_os.top();
+      m_co->setVersion(elAttrs.value("version"));
       m_co->setPm (pMain); // pass the 'main' pointer to the sub object
       return (true);
     }
@@ -952,6 +1008,15 @@ MyMoneyGncReader::MyMoneyGncReader() {
   m_smallBusinessFound = m_budgetsFound = m_lotsFound = false;
   m_commodityCount = m_priceCount = m_accountCount = m_transactionCount = m_templateCount = m_scheduleCount = 0;
   m_decoder = 0;
+  // build a list of valid versions
+  static const QString versionList[] = {"gnc:book 2.0.0", "gnc:commodity 2.0.0", "gnc:pricedb 1",
+                                        "gnc:account 2.0.0", "gnc:transaction 2.0.0", "gnc:schedxaction 1.0.0",
+                                        "gnc:schedxaction 2.0.0", // for gnucash 2.2 onward
+                                        "gnc:freqspec 1.0.0", "zzz" // zzz = stopper
+                                       };
+  unsigned int i;
+  for (i = 0; versionList[i] != "zzz"; ++i)
+    m_versionList[versionList[i].section (' ', 0, 0)].append(versionList[i].section (' ', 1, 1));
 }
 
 //***************** Destructor *************************
@@ -971,16 +1036,18 @@ void MyMoneyGncReader::readFile(QIODevice* pDevice, IMyMoneySerialize* storage)
   if (bAnonymize) setFileHideFactor ();
   //m_defaultPayee = createPayee (i18n("Unknown payee"));
 
+//  MyMoneyFileTransaction ft;
   m_xr = new XmlReader (this);
   try {
     m_xr->processFile (pDevice);
     terminate (); // do all the wind-up things
+//    ft.commit();
   } catch (MyMoneyException *e) {
     QMessageBox::critical (0, PACKAGE, i18n("Import failed\n\n") + e->what(),
                            QMessageBox::Abort, QMessageBox::NoButton , QMessageBox::NoButton);
     qFatal ("%s", e->what().latin1());
   } // end catch
-  signalProgress ( -1, -1); // switch off progress bar
+  signalProgress (0, 1, i18n("Import complete")); // switch off progress bar
   delete m_xr;
   qDebug ("Exiting gnucash importer");
   return ;
@@ -1060,6 +1127,7 @@ void MyMoneyGncReader::convertCommodity (const GncCommodity *gcm) {
     equ.setTradingCurrency (""); // not available here, will set from pricedb or transaction
     equ.setSecurityType (MyMoneySecurity::SECURITY_STOCK); // default to it being a stock
     //tell the storage objects we have a new equity object.
+    equ.setSmallestAccountFraction(gcm->fraction().toInt());
     m_storage->addSecurity(equ);
 
     //assign the gnucash id as the key into the map to find our id
@@ -1097,6 +1165,11 @@ void MyMoneyGncReader::convertPrice (const GncPrice *gpr) {
 void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
   Q_CHECK_PTR (gac);
   TRY
+  // we don't care about the GNC root account
+  if("ROOT" == gac->type()) {
+      m_rootId = gac->id().utf8();
+      return;
+  }
 
   MyMoneyAccount acc;
   if (m_accountCount == 0) signalProgress (0, m_gncAccountCount, i18n("Loading accounts..."));
@@ -1119,7 +1192,7 @@ void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
 # Feb 2006: A RELAX NG Compact schema for gnucash "v2" XML files.
 # Copyright (C) 2006 Joshua Sled <jsled@asynchronous.org>
 "NO_TYPE" "BANK" "CASH" "CREDIT" "ASSET" "LIABILITY" "STOCK" "MUTUAL" "CURRENCY"
-"INCOME" "EXPENSE" "EQUITY" "RECEIVABLE" "PAYABLE" "CHECKING" "SAVINGS" "MONEYMRKT" "CREDITLINE" 
+"INCOME" "EXPENSE" "EQUITY" "RECEIVABLE" "PAYABLE" "CHECKING" "SAVINGS" "MONEYMRKT" "CREDITLINE"
   Some don't seem to be used in practice. Not sure what CREDITLINE s/be converted as.
   */
   if ("BANK" == gac->type() || "CHECKING" == gac->type()) {
@@ -1164,7 +1237,7 @@ void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
     throw new MYMONEYEXCEPTION (em);
   }
   // if no parent account is present, assign to one of our standard accounts
-  if (acc.parentAccountId().isEmpty()) {
+  if ((acc.parentAccountId().isEmpty()) || (acc.parentAccountId() == m_rootId)) {
     switch (acc.accountGroup()) {
     case MyMoneyAccount::Asset: acc.setParentAccountId (m_storage->asset().id()); break;
     case MyMoneyAccount::Liability: acc.setParentAccountId (m_storage->liability().id()); break;
@@ -1204,7 +1277,7 @@ void MyMoneyGncReader::convertAccount (const GncAccount* gac) {
       }
     }
   }
-  
+
   // check for tax-related status
   QPtrListIterator<GncObject> kvpi (gac->m_kvpList);
   GncKvp *k;
@@ -1341,7 +1414,7 @@ void MyMoneyGncReader::convertSplit (const GncSplit *gsp) {
   // 3. others (categories)
   // but keeping each in same order as gnucash
   MyMoneySecurity e;
-  MyMoneyMoney price, newPrice;
+  MyMoneyMoney price, newPrice(0);
 
   switch (splitAccount.accountGroup()) {
   case MyMoneyAccount::Asset:
@@ -1355,14 +1428,15 @@ void MyMoneyGncReader::convertSplit (const GncSplit *gsp) {
       // newPrice fix supplied by Phil Longstaff
       price = split.value() / split.shares();
 #define NEW_DENOM 10000
-      newPrice = MyMoneyMoney ( price.toDouble(), (signed64)NEW_DENOM );
+      if (!split.shares().isZero())  // patch to fix divide by zero?
+        newPrice = MyMoneyMoney ( price.toDouble(), (signed64)NEW_DENOM );
       if (!newPrice.isZero()) {
         TRY
           // we can't use m_storage->security coz security list is not built yet
           m_storage->currency(m_txCommodity);   // will throw exception if not currency
           e.setTradingCurrency (m_txCommodity);
           if (gncdebug) qDebug ("added price for %s, %s date %s",
-              e.name().latin1(), price.toString().latin1(),
+              e.name().latin1(), newPrice.toString().latin1(),
               m_txDatePosted.toString(Qt::ISODate).latin1());
           m_storage->modifySecurity(e);
           MyMoneyPrice dealPrice (e.id(), m_txCommodity, m_txDatePosted, newPrice, i18n("Imported Transaction"));
@@ -1633,9 +1707,9 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
   } else {
     tx = convertTemplateTransaction (sc.name(), *itt);
   }
-  tx.setId("");
-  sc.setTransaction(tx);
-  // define the conversion table for intervals
+  tx.setId(QString());
+
+// define the conversion table for intervals
   struct convIntvl {
     QString gncType; // the gnucash name
     unsigned char interval; // for date calculation
@@ -1643,34 +1717,68 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
     MyMoneySchedule::occurenceE occ; // equivalent occurence code
     MyMoneySchedule::weekendOptionE wo;
   };
-  /* other intervals supported by gnc according to Josh Sled's schema (see above)
-   "none" "semi_monthly"
-   */
+/* other intervals supported by gnc according to Josh Sled's schema (see above)
+ "none" "semi_monthly"
+ */
+  /* some of these type names do not appear in gnucash and are difficult to generate for
+  pre 2.2 files.They can be generated for 2.2 however, by GncRecurrence::getFrequency() */
   static convIntvl vi [] = {
-                             {"once", 'o', 1, MyMoneySchedule::OCCUR_ONCE, MyMoneySchedule::MoveNothing },
-                             {"daily" , 'd', 1, MyMoneySchedule::OCCUR_DAILY, MyMoneySchedule::MoveNothing },
-                             //{"daily_mf", 'd', 1, MyMoneySchedule::OCCUR_DAILY, MyMoneySchedule::MoveMonday }, doesn't work, need new freq in kmm
-                             {"weekly", 'w', 1, MyMoneySchedule::OCCUR_WEEKLY, MyMoneySchedule::MoveNothing },
-                             {"bi_weekly", 'w', 2, MyMoneySchedule::OCCUR_EVERYOTHERWEEK, MyMoneySchedule::MoveNothing },
-                             {"monthly", 'm', 1, MyMoneySchedule::OCCUR_MONTHLY, MyMoneySchedule::MoveNothing },
-                             {"quarterly", 'm', 3, MyMoneySchedule::OCCUR_QUARTERLY, MyMoneySchedule::MoveNothing },
-                             {"tri_annually", 'm', 4, MyMoneySchedule::OCCUR_EVERYFOURMONTHS, MyMoneySchedule::MoveNothing },
-                             {"semi_yearly", 'm', 6, MyMoneySchedule::OCCUR_TWICEYEARLY, MyMoneySchedule::MoveNothing },
-                             {"yearly", 'y', 1, MyMoneySchedule::OCCUR_YEARLY, MyMoneySchedule::MoveNothing },
-                             {"zzz", 'y', 1, MyMoneySchedule::OCCUR_YEARLY, MyMoneySchedule::MoveNothing}
-                              // zzz = stopper, may cause problems. what else can we do?
+                           {"once", 'o', 1, MyMoneySchedule::OCCUR_ONCE, MyMoneySchedule::MoveNothing },
+                           {"daily" , 'd', 1, MyMoneySchedule::OCCUR_DAILY, MyMoneySchedule::MoveNothing },
+                           //{"daily_mf", 'd', 1, MyMoneySchedule::OCCUR_DAILY, MyMoneySchedule::MoveMonday }, doesn't work, need new freq in kmm
+                           {"weekly", 'w', 1, MyMoneySchedule::OCCUR_WEEKLY, MyMoneySchedule::MoveNothing },
+                           {"bi_weekly", 'w', 2, MyMoneySchedule::OCCUR_EVERYOTHERWEEK, MyMoneySchedule::MoveNothing },
+                           {"four-weekly", 'w', 4, MyMoneySchedule::OCCUR_EVERYFOURWEEKS,
+                           MyMoneySchedule::MoveNothing },
+                           {"monthly", 'm', 1, MyMoneySchedule::OCCUR_MONTHLY, MyMoneySchedule::MoveNothing },
+                           {"two-monthly", 'm', 2, MyMoneySchedule::OCCUR_EVERYOTHERMONTH,
+                            MyMoneySchedule::MoveNothing },
+                           {"quarterly", 'm', 3, MyMoneySchedule::OCCUR_QUARTERLY, MyMoneySchedule::MoveNothing },
+                           {"tri_annually", 'm', 4, MyMoneySchedule::OCCUR_EVERYFOURMONTHS, MyMoneySchedule::MoveNothing },
+                           {"semi_yearly", 'm', 6, MyMoneySchedule::OCCUR_TWICEYEARLY, MyMoneySchedule::MoveNothing },
+                           {"yearly", 'y', 1, MyMoneySchedule::OCCUR_YEARLY, MyMoneySchedule::MoveNothing },
+                           {"two-yearly", 'y', 2, MyMoneySchedule::OCCUR_EVERYOTHERYEAR,
+                            MyMoneySchedule::MoveNothing },
+                           {"zzz", 'y', 1, MyMoneySchedule::OCCUR_YEARLY, MyMoneySchedule::MoveNothing}
+                            // zzz = stopper, may cause problems. what else can we do?
                            };
-  // find this interval
-  const GncFreqSpec *fs = gsc->getFreqSpec();
+
+  QString frequency = "unknown"; // set default to unknown frequency
+  bool unknownOccurs = false; // may have zero, or more than one frequency/recurrence spec
+  QString schedEnabled;
+  if (gsc->version() == "2.0.0") {
+    if (gsc->m_vpRecurrence.count() != 1) {
+      unknownOccurs = true;
+    } else {
+      const GncRecurrence *gre = gsc->m_vpRecurrence.first();
+      //qDebug (QString("Sched %1, pt %2, mu %3, sd %4").arg(gsc->name()).arg(gre->periodType())
+       // .arg(gre->mult()).arg(gre->startDate().toString(Qt::ISODate)));
+      frequency = gre->getFrequency();
+      schedEnabled = gsc->enabled();
+    }
+    sc.setOccurence(MyMoneySchedule::OCCUR_ONCE); // FIXME - how to convert
+  } else {
+    // find this interval
+    const GncFreqSpec *fs = gsc->getFreqSpec();
+    if (fs == NULL) {
+      unknownOccurs = true;
+    } else {
+      frequency = fs->intervalType();
+      if (!fs->m_fsList.isEmpty()) unknownOccurs = true; // nested freqspec
+    }
+    schedEnabled = "y"; // earlier versions did not have an enable flag
+  }
+
   int i;
   for (i = 0; vi[i].gncType != "zzz"; i++) {
-    if (fs->intervalType() == vi[i].gncType) break;
+    if (frequency == vi[i].gncType) break;
   }
   if (vi[i].gncType == "zzz") {
-    postMessage ("SC", 1, sc.name().latin1(), fs->intervalType().latin1());
+    postMessage ("SC", 1, sc.name().latin1(), frequency.latin1());
+    i = 0; // treat as single occurrence
     m_suspectSchedule = true;
   }
-  if (!fs->m_fsList.isEmpty()) {
+  if (unknownOccurs) {
     postMessage ("SC", 7, sc.name().latin1());
     m_suspectSchedule = true;
   }
@@ -1682,13 +1790,16 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
   sc.setLastPayment(gsc->lastDate());
   numOccurs = gsc->numOccurs().toInt();
   if (sc.lastPayment() == QDate()) {
-    nextDate = gsc->startDate();
+    nextDate = lastDate = gsc->startDate();
     while (nextDate < today) {
       lastDate = nextDate;
       nextDate = incrDate (lastDate, vi[i].interval, vi[i].intervalCount);
     }
     sc.setLastPayment(lastDate);
   }
+  // under Tom's new regime, the tx dates are the next due date (I think)
+  tx.setPostDate(incrDate(sc.lastPayment(), vi[i].interval, vi[i].intervalCount));
+  tx.setEntryDate(incrDate(sc.lastPayment(), vi[i].interval, vi[i].intervalCount));
   // if an end date was specified, use it, otherwise if the input file had a number
   // of occurs remaining, work out the end date
   sc.setEndDate(gsc->endDate());
@@ -1702,13 +1813,16 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
   }
   // Check for sched deferred interval. Don't know how/if we can handle it, or even what it means...
   if (gsc->getSchedDef() != NULL) {
-    // FIXME: we really need to post a specific error message here, but we're on a string freeze for 0.8. Do it for 1.0
+    postMessage ("SC", 8, sc.name().latin1());
     m_suspectSchedule = true;
   }
   // payment type, options
   sc.setPaymentType((MyMoneySchedule::paymentTypeE)MyMoneySchedule::STYPE_OTHER);
   sc.setFixed (!m_suspectSchedule); // if any probs were found, set it as variable so user will always be prompted
-  sc.setAutoEnter (gsc->autoCreate() == "y");
+  // we don't currently have a 'disable' option, but just make sure auto-enter is off if not enabled
+  //qDebug(QString("%1 and %2").arg(gsc->autoCreate()).arg(schedEnabled));
+  sc.setAutoEnter ((gsc->autoCreate() == "y") && (schedEnabled == "y"));
+  //qDebug(QString("autoEnter set to %1").arg(sc.autoEnter()));
   // type
   QCString actionType = tx.splits().first().action();
   if (actionType == MyMoneySplit::ActionDeposit) {
@@ -1718,6 +1832,8 @@ void MyMoneyGncReader::convertSchedule (const GncSchedule *gsc) {
   } else {
     sc.setType((MyMoneySchedule::typeE)MyMoneySchedule::TYPE_BILL);
   }
+  // finally, set the transaction pointer
+  sc.setTransaction(tx);
   //tell the storage objects we have a new schedule object.
   if (m_suspectSchedule && m_dropSuspectSchedules) {
     postMessage ("SC", 2, sc.name().latin1());
@@ -1736,13 +1852,18 @@ void MyMoneyGncReader::convertFreqSpec (const GncFreqSpec *) {
   // but we will probably need to look into the nested freqspec when we properly implement semi-monthly and stuff
   return ;
 }
+//********************************* convertRecurrence  ********************************************************
+void MyMoneyGncReader::convertRecurrence (const GncRecurrence *) {
+  return ;
+}
+
 //**********************************************************************************************************
 //************************************* terminate **********************************************************
 void MyMoneyGncReader::terminate () {
   TRY
   // All data has been converted and added to storage
   // this code is just temporary to show us what is in the file.
-  if (gncdebug) qDebug("%d accounts found in the GNU Cash file", (unsigned int)m_mapIds.count());
+  if (gncdebug) qDebug("%d accounts found in the GnuCash file", (unsigned int)m_mapIds.count());
   for (map_accountIds::Iterator it = m_mapIds.begin(); it != m_mapIds.end(); ++it) {
     if (gncdebug) qDebug("key = %s, value = %s", it.key().data(), it.data().data());
   }
@@ -1779,6 +1900,8 @@ void MyMoneyGncReader::terminate () {
       MyMoneyAccount equity = m_storage->equity();
       m_storage->addAccount(equity, (*acc));
       if (gncdebug) qDebug("Account id %s is a child of the main equity account", (*acc).id().data());
+    } else if ((*acc).parentAccountId() == m_rootId) {
+      if (gncdebug) qDebug("Account id %s is a child of root", (*acc).id().data());
     } else {
       // it is not under one of the main accounts, so find gnucash parent
       QCString parentKey = (*acc).parentAccountId();
@@ -1797,6 +1920,7 @@ void MyMoneyGncReader::terminate () {
     }
     signalProgress (++i, 0);
   } // end for account
+  signalProgress (0, 1, (".")); // debug - get rid of reorg message
   // offer the most common account currency as a default
   QString mainCurrency = "";
   unsigned int maxCount = 0;
@@ -1834,11 +1958,11 @@ void MyMoneyGncReader::terminate () {
   // produce the sections in message boxes
   bool exit = false;
   for (i = 0; (i < sectionsToReport.count()) && !exit; i++) {
-    QString button0Text = "More";
-    if (i + 1 == sectionsToReport.count()) button0Text = "Done"; // last section
+    QString button0Text = i18n("More");
+    if (i + 1 == sectionsToReport.count()) button0Text = i18n("Done"); // last section
     switch (QMessageBox::information (0, PACKAGE,
                                       buildReportSection (*sectionsToReport.at(i)),
-                                      button0Text, "Save Report", "Cancel",
+                                      button0Text, i18n("Save Report"), i18n("Cancel"),
                                       0, 2))    // Enter == button 0, Escape == button 2
     {
     case 0:
@@ -1862,7 +1986,7 @@ void MyMoneyGncReader::terminate () {
                     QMessageBox::NoButton);
     switch (mb.exec()) {
     case QMessageBox::Yes:
-        KEditScheduleDialog *s = new  KEditScheduleDialog (sc.transaction().splits()[0].action(), sc, 0, "");
+         KEditScheduleDialog *s = new  KEditScheduleDialog (sc.transaction().splits()[0].action(), sc, 0, "");
         // FIXME: connect newCategory to something useful, so that we
         // can create categories from within the dialog
         if (s->exec())
@@ -1912,10 +2036,13 @@ const QString MyMoneyGncReader::buildReportSection (const QString source) {
     }
     if (more) s.append (i18n("\n\nPress More for further information"));
   } else { // we need to retrieve the posted messages for this source
+    if (gncdebug) qDebug("Building messages for source %s", source.latin1());
     unsigned int i, j;
     for (i = 0; i < m_messageList.count(); i++) {
       GncMessageArgs *m = m_messageList.at(i);
       if (m->source == source) {
+        if (gncdebug) qDebug(QString("build text source %1, code %2, argcount %3")
+              .arg(m->source).arg(m->code).arg(m->args.count()));
         QString ss = GncMessages::text (m->source, m->code);
         // add variable args. the .arg function seems always to replace the
         // lowest numbered placeholder it finds, so translating messages
@@ -1944,6 +2071,7 @@ bool MyMoneyGncReader::writeReportToFile (const QValueList<QString> sectionsToRe
     stream << buildReportSection (*sectionsToReport.at(i)).latin1() << endl;
   }
   reportFile.close();
+  delete fd;
   return (true);
   PASS
 }
@@ -2146,6 +2274,13 @@ void MyMoneyGncReader::checkInvestmentOption (QString stockId) {
 
 // get the price source for a stock (gnc account) where online quotes are requested
 void MyMoneyGncReader::getPriceSource (MyMoneySecurity stock, QString gncSource) {
+  // if he wants to use Finance::Quote, no conversion of source name is needed
+  if (m_useFinanceQuote) {
+    stock.setValue ("kmm-online-quote-system", "Finance::Quote");
+    stock.setValue ("kmm-online-source", gncSource.lower());
+    m_storage->modifySecurity(stock);
+    return;
+  }
   // first check if we have already asked about this source
   // (mapSources is initialy empty. We may be able to pre-fill it with some equivalent
   //  sources, if such things do exist. User feedback may help here.)
@@ -2183,8 +2318,21 @@ void MyMoneyGncReader::signalProgress(int current, int total, const QString& msg
 }
 // error and information reporting
 //***************************** Information and error messages *********************
-void MyMoneyGncReader::postMessage (const QString source, const unsigned int code, ...) {
-  TRY
+void MyMoneyGncReader::postMessage (const QString source, const unsigned int code, const char* arg1) {
+  postMessage (source, code, QStringList(arg1));
+}
+void MyMoneyGncReader::postMessage (const QString source, const unsigned int code, const char* arg1, const char* arg2) {
+  QStringList argList(arg1);
+  argList.append(arg2);
+  postMessage(source, code, argList);
+}
+void MyMoneyGncReader::postMessage (const QString source, const unsigned int code, const char* arg1, const char* arg2, const char* arg3) {
+  QStringList argList(arg1);
+  argList.append(arg2);
+  argList.append(arg3);
+  postMessage(source, code, argList);
+}
+void MyMoneyGncReader::postMessage (const QString source, const unsigned int code, const QStringList& argList) {
   unsigned int i;
   GncMessageArgs *m = new GncMessageArgs;
 
@@ -2192,21 +2340,17 @@ void MyMoneyGncReader::postMessage (const QString source, const unsigned int cod
   m->code = code;
   // get the number of args this message requires
   const unsigned int argCount = GncMessages::argCount (source, code);
-  // incredibly, va cannot for some reason provide a count of the args it contains
-  // so we may get a seg fault if not enough are provided
-  // the following debug may help trace the cause
-  if (gncdebug) qDebug
-    ("MyMoneyGncReader::postMessage: Message %s, code %d, requires %d arguments of type char *, else may segfault",
-     source.latin1(), code, argCount);
+  if ((gncdebug) && (argCount != argList.count()))
+    qDebug
+    (QString("MyMoneyGncReader::postMessage debug: Message %1, code %2, requires %3 arguments, got %4")
+        .arg(source).arg(code).arg(argCount).arg(argList.count()));
   // store the arguments
-  va_list arguments;
-  va_start(arguments, code); //Initializing arguments to store all values passed in after code
-  for (i = 0; i < argCount; i++)
-    m->args.append (QString(va_arg(arguments, char *))); //Adds the next argument to the list
-  va_end(arguments);      //Cleans up the list
+  for (i = 0; i < argCount; i++) {
+    if (i > argList.count()) m->args.append(QString());
+    else m->args.append (argList[i]); //Adds the next argument to the list
+  }
   m_messageList.append (m);
   return ;
-  PASS
 }
 //********************************** Message texts **********************************************
 GncMessages::messText GncMessages::texts [] = {
@@ -2224,7 +2368,8 @@ GncMessages::messText GncMessages::texts [] = {
       {"SC", 4, i18n("Schedule %1 contains multiple actions; only one has been imported")},
       {"SC", 5, i18n("Schedule %1 contains no valid splits")},
       {"SC", 6, i18n("Schedule %1 appears to contain a formula. GnuCash formulae are not convertible")},
-      {"SC", 7, i18n("Schedule %1 contains a composite interval specification; please check for correct operation")},
+      {"SC", 7, i18n("Schedule %1 contains unknown interval specification; please check for correct operation")},
+      {"SC", 8, i18n("Schedule %1 contains a deferred interval specification; please check for correct operation")},
       {"CC", 4, i18n("Account or Category %1, transaction date %2; split contains invalid value; please check")},
       {"ZZ", 0, ""} // stopper
     };
