@@ -192,12 +192,12 @@ void MyMoneyQifWriter::writeTransactionEntry(QTextStream &s, const MyMoneyTransa
     if(acc.accountGroup() != MyMoneyAccount::Income
     && acc.accountGroup() != MyMoneyAccount::Expense) {
       s << "L" << m_qifProfile.accountDelimiter()[0]
-             << acc.name()
-             << m_qifProfile.accountDelimiter()[1] << endl;
+              << MyMoneyFile::instance()->accountToCategory(sp.accountId())
+              << m_qifProfile.accountDelimiter()[1] << endl;
     } else {
       s << "L" << file->accountToCategory(sp.accountId()) << endl;
     }
-    if(t.splitCount() > 2) {
+    if(list.count() > 2) {
       QValueList<MyMoneySplit>::ConstIterator it;
       for(it = list.begin(); it != list.end(); ++it) {
         if(!((*it) == split)) {
@@ -230,3 +230,5 @@ void MyMoneyQifWriter::writeSplitEntry(QTextStream& s, const MyMoneySplit& split
 
   s << "$" << m_qifProfile.value('$', -split.value()) << endl;
 }
+
+#include "mymoneyqifwriter.moc"
