@@ -57,7 +57,7 @@ bool WebPriceQuote::launch( const QString& _symbol, const QString& _id, const QS
   m_id = _id;
 
 //   emit status(QString("(Debug) symbol=%1 id=%2...").arg(_symbol,_id));
-  
+
   // if we're running normally, with a UI, we can just get these the normal way,
   // from the config file
   if ( kapp )
@@ -189,7 +189,7 @@ void WebPriceQuote::slotParseQuote(const QString& _quotedata)
     // Extra white space
     quotedata = quotedata.simplifyWhiteSpace();
 
-#ifdef KMM_DEBUG
+#if KMM_DEBUG
     // Enable to get a look at the data coming back from the source after it's stripped
     QFile file("stripped.txt");
     if ( file.open( IO_WriteOnly ) )
@@ -297,6 +297,15 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
     "[^,]*,[^,]*,\"([^\"]*)\"", // dateregexp
     "%m %d %y" // dateformat
   );
+  // sl1d1 format for Yahoo France doesn't seem to give a date ever
+  // sl1d3 gives us time (99h99) and date
+  result["Yahoo France"] = WebPriceQuoteSource("Yahoo France",
+    "http://fr.finance.yahoo.com/d/quotes.csv?s=%1&f=sl1d3",
+    "([^;]*).*",             // symbolregexp
+    "[^;]*.([^;]*),*",       // priceregexp
+    "[^;]*.[^;]*...h...([^;]*)", // dateregexp
+    "%d/%m/%y"               // dateformat
+  );
 
   result["Globe & Mail"] = WebPriceQuoteSource("Globe & Mail",
     "http://globefunddb.theglobeandmail.com/gishome/plsql/gis.price_history?pi_fund_id=%1",
@@ -337,7 +346,7 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
   // stands for Hamburg.
   //
   // Here the id for several market places: 2 Frankfurt, 3 Berlin, 4
-  // Dsseldorf, 5 Hamburg, 6 Mnchen/Munich, 7 Hannover, 9 Stuttgart, 10
+  // Düsseldorf, 5 Hamburg, 6 München/Munich, 7 Hannover, 9 Stuttgart, 10
   // Xetra, 32 NASDAQ, 36 NYSE
 
   result["Wallstreet-Online.DE (Hamburg)"] = WebPriceQuoteSource("Wallstreet-Online.DE (Hamburg)",
@@ -348,6 +357,25 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
     "%d %m %y" // dateformat
   );
 
+  // The following price quote was contributed by
+  // Piotr Adacha <piotr.adacha@googlemail.com>
+
+  // I would like to post new Online Query Settings for KMyMoney. This set is
+  // suitable to query stooq.com service, providing quotes for stocks, futures,
+  // mutual funds and other financial instruments from Polish Gielda Papierow
+  // Wartosciowych (GPW). Unfortunately, none of well-known international
+  // services provide quotes for this market (biggest one in central and eastern
+  // Europe), thus, I think it could be helpful for Polish users of KMyMoney (and
+  // I am one of them for almost a year).
+
+  result["Gielda Papierow Wartosciowych (GPW)"] = WebPriceQuoteSource("Gielda Papierow Wartosciowych (GPW)",
+    "http://stooq.com/q/?s=%1",
+    QString(),                      // symbol regexp
+    "Kurs.*(\\d+\\.\\d+).*Data",    // price regexp
+    "(\\d{4,4}-\\d{2,2}-\\d{2,2})", // date regexp
+    "%y %m %d"                      // date format
+  );
+
   return result;
 }
 
