@@ -24,11 +24,8 @@
 // KDE Includes
 
 #include <kglobal.h>
-#if QT_VERSION > 300
 #include <kstandarddirs.h>
-#else
-#include <kstddirs.h>
-#endif
+#include <kapplication.h>
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -45,7 +42,7 @@ KEndingBalanceDlg::KEndingBalanceDlg(const MyMoneyAccount& account, QWidget *par
   QString value;
 
   m_account = account;
-    
+
   // If the previous reconciliation was postponed,
   // we show a different first page
   value = account.value("lastReconciledBalance");
@@ -63,12 +60,23 @@ KEndingBalanceDlg::KEndingBalanceDlg(const MyMoneyAccount& account, QWidget *par
     // make sure, we show the correct start page
     showPage(m_pagePreviousPostpone);
   }
-  
-  m_previousBalance->loadText(MyMoneyMoney(value).formatMoney());
+
+  // We don't need to add the default into the list (see ::help() why)
+  // m_helpAnchor[m_startPageCheckings] = QString("");
+  m_helpAnchor[m_interestChargeCheckings] = QString("details.reconcile.wizard.interest");
+  m_helpAnchor[m_statementInfoPageCheckings] = QString("details.reconcile.wizard.statement");
+
+  if(m_account.accountGroup() == MyMoneyAccount::Liability)
+    m_previousBalance->loadText((-MyMoneyMoney(value)).formatMoney());
+  else
+    m_previousBalance->loadText(MyMoneyMoney(value).formatMoney());
 
   value = account.value("statementBalance");
-  m_endingBalance->loadText(MyMoneyMoney(value).formatMoney());
-  
+  if(m_account.accountGroup() == MyMoneyAccount::Liability)
+    m_endingBalance->loadText((-MyMoneyMoney(value)).formatMoney());
+  else
+    m_endingBalance->loadText(MyMoneyMoney(value).formatMoney());
+
   m_statementDate->setDate(QDate::currentDate());
   value = account.value("statementDate");
   if(!value.isEmpty())
@@ -85,9 +93,6 @@ KEndingBalanceDlg::KEndingBalanceDlg(const MyMoneyAccount& account, QWidget *par
   removePage(m_startPageLoan);
   removePage(m_checkPaymentsPage);
   removePage(m_adjustmentTransactionPage);
-  
-  // FIXME: we need the online help first
-  helpButton()->hide();
 
   // connect the signals with the slots
   connect(m_interestEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotCheckPageFinished(void)));
@@ -95,19 +100,16 @@ KEndingBalanceDlg::KEndingBalanceDlg(const MyMoneyAccount& account, QWidget *par
   connect(m_chargesEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotCheckPageFinished(void)));
   connect(m_chargesCategoryEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotCheckPageFinished(void)));
 /*
-   //QString filename = KGlobal::dirs()->findResource("appdata", "pics/dlg_ending_balance.png");
-  m_qpixmaplabel->setPixmap(QPixmap(KGlobal::dirs()->findResource("appdata", "pics/dlg_ending_balance.png")));
+  previousbalEdit->setText(prevBal.formatMoney());
+  previousbalEdit->setFocus();
+  previousbalEdit->setSelection(0, previousbalEdit->text().length());
 
-	previousbalEdit->setText(prevBal.formatMoney());
-	previousbalEdit->setFocus();
-	previousbalEdit->setSelection(0, previousbalEdit->text().length());	
-	
-	endingEdit->setText(endingGuess.formatMoney());
+  endingEdit->setText(endingGuess.formatMoney());
 
   endingDateEdit->setDate(statementDate);
-	
-	connect(cancelBtn, SIGNAL(clicked()), SLOT(reject()));
-	connect(okBtn, SIGNAL(clicked()), SLOT(okClicked()));
+
+  connect(cancelBtn, SIGNAL(clicked()), SLOT(reject()));
+  connect(okBtn, SIGNAL(clicked()), SLOT(okClicked()));
 */
 }
 
@@ -115,11 +117,26 @@ KEndingBalanceDlg::~KEndingBalanceDlg()
 {
 }
 
+const MyMoneyMoney KEndingBalanceDlg::endingBalance(void) const
+{
+  return adjustedReturnValue(m_endingBalance->value());
+}
+
+const MyMoneyMoney KEndingBalanceDlg::previousBalance(void) const
+{
+  return adjustedReturnValue(m_previousBalance->value());
+}
+
+const MyMoneyMoney KEndingBalanceDlg::adjustedReturnValue(const MyMoneyMoney& v) const
+{
+  return m_account.accountGroup() == MyMoneyAccount::Liability ? -v : v;
+}
+
 void KEndingBalanceDlg::slotCheckPageFinished(void)
 {
   nextButton()->setEnabled(true);
   finishButton()->setEnabled(true);
-  
+
   if(currentPage() == m_interestChargeCheckings) {
     int cnt1, cnt2;
     cnt1 = !m_interestEdit->text().isEmpty() + !m_interestCategoryEdit->text().isEmpty();
@@ -145,12 +162,12 @@ const MyMoneyTransaction KEndingBalanceDlg::createTransaction(const int sign, kM
 {
   MyMoneyTransaction t;
   MyMoneyFile* file = MyMoneyFile::instance();
-  
+
   if(!amountEdit->isValid() || categoryEdit->text().isEmpty())
     return t;
 
   MyMoneySplit s1, s2;
-  MyMoneyMoney val = amountEdit->getMoneyValue() * sign;
+  MyMoneyMoney val = amountEdit->value() * MyMoneyMoney(sign,1);
   try {
     QCString accId = file->categoryToAccount(categoryEdit->text());
     if(accId.isEmpty())
@@ -172,7 +189,7 @@ const MyMoneyTransaction KEndingBalanceDlg::createTransaction(const int sign, kM
       s1.setAction(MyMoneySplit::ActionWithdrawal);
     else
       s1.setAction(MyMoneySplit::ActionDeposit);
-          
+
     s1.setReconcileFlag(MyMoneySplit::Cleared);
     s1.setReconcileDate(QDate::currentDate());
     s2 = s1;
@@ -185,31 +202,39 @@ const MyMoneyTransaction KEndingBalanceDlg::createTransaction(const int sign, kM
     t.addSplit(s1);
     t.addSplit(s2);
     t.setPostDate(m_statementDate->getQDate());
-    
+
   } catch(MyMoneyException *e) {
     qDebug("%s", e->what().data());
     delete e;
     return MyMoneyTransaction();
   }
-  
+
   return t;
 }
 
+void KEndingBalanceDlg::help(void)
+{
+  QString anchor = m_helpAnchor[currentPage()];
+  if(anchor.isEmpty())
+    anchor = QString("details.reconcile.whatis");
+
+  kapp->invokeHelp(anchor);
+}
 
 KEndingBalanceLoanDlg::KEndingBalanceLoanDlg(const MyMoneyAccount& account, QWidget *parent, const char *name)
  : KEndingBalanceDlgDecl(parent, name, true),
    m_account(account)
 {
-  QString value;  
+  QString value;
   value = account.value("lastStatementDate");
   if(value.isEmpty())
     m_startDateEdit->setDate(m_account.openingDate());
   else
     m_startDateEdit->setDate(QDate::fromString(value, Qt::ISODate).addDays(1));
-  
+
   // make sure, we show the correct start page
   showPage(m_startPageLoan);
-  
+
   // enable the finish button on the last page
   setAppropriate(m_checkPaymentsPage, true);
 
@@ -218,10 +243,7 @@ KEndingBalanceLoanDlg::KEndingBalanceLoanDlg(const MyMoneyAccount& account, QWid
   removePage(m_statementInfoPageCheckings);
   removePage(m_pagePreviousPostpone);
   removePage(m_interestChargeCheckings);
-  
-  // FIXME: we need the online help first
-  helpButton()->hide();
-  
+
   // connect the signals with the slots
   connect(m_amortizationTotalEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotCheckPageFinished(void)));
   connect(m_interestTotalEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotCheckPageFinished(void)));
@@ -242,8 +264,8 @@ void KEndingBalanceLoanDlg::slotCheckPageFinished(void)
     MyMoneyMoney interest = totalInterest(m_startDateEdit->getQDate(), m_endDateEdit->getQDate());
     MyMoneyMoney amortization = totalAmortization(m_startDateEdit->getQDate(), m_endDateEdit->getQDate());
 
-    if(interest == m_interestTotalEdit->getMoneyValue()
-    && amortization == m_amortizationTotalEdit->getMoneyValue()) {
+    if(interest == m_interestTotalEdit->value()
+    && amortization == m_amortizationTotalEdit->value()) {
       if(indexOf(m_adjustmentTransactionPage) != -1) {
         removePage(m_adjustmentTransactionPage);
         // the following line forces to update the buttons
@@ -262,7 +284,7 @@ void KEndingBalanceLoanDlg::slotCheckPageFinished(void)
     if(m_accountEdit->selectedAccounts().count() == 0) {
       nextButton()->setEnabled(false);
       finishButton()->setEnabled(false);
-      
+
     } else if(m_categoryEdit->isEnabled()
     && m_categoryEdit->selectedAccounts().count() == 0) {
       nextButton()->setEnabled(false);
@@ -294,13 +316,13 @@ const MyMoneyMoney KEndingBalanceLoanDlg::totalInterest(const QDate& start, cons
 const MyMoneyMoney KEndingBalanceLoanDlg::totalAmortization(const QDate& start, const QDate& end) const
 {
   MyMoneyMoney  amortization;
-  int           adjust = 1;
+  MyMoneyMoney  adjust(1,1);
   MyMoneyTransactionFilter  filter(m_account.id());
   filter.setDateFilter(start, end);
 
   if(m_account.accountType() == MyMoneyAccount::AssetLoan)
-    adjust = -1;
-    
+    adjust = -adjust;
+
   QValueList<MyMoneyTransaction> list = MyMoneyFile::instance()->transactionList(filter);
   QValueList<MyMoneyTransaction>::ConstIterator it_t;
 
@@ -309,7 +331,7 @@ const MyMoneyMoney KEndingBalanceLoanDlg::totalAmortization(const QDate& start,
     for(it_s = (*it_t).splits().begin(); it_s != (*it_t).splits().end(); ++it_s) {
       if((*it_s).accountId() == m_account.id()
       && (*it_s).action() == MyMoneySplit::ActionAmortization
-      && ((*it_s).value() * adjust) > 0) {
+      && ((*it_s).value() * MyMoneyMoney(adjust, 1)).isPositive()) {
         amortization += (*it_s).value();
       }
     }
@@ -321,7 +343,7 @@ const MyMoneyMoney KEndingBalanceLoanDlg::totalAmortization(const QDate& start,
 void KEndingBalanceLoanDlg::next(void)
 {
   bool dontLeavePage = false;
-  
+
   if(currentPage() == m_startPageLoan) {
     MyMoneyMoney interest = totalInterest(m_startDateEdit->getQDate(), m_endDateEdit->getQDate());
     MyMoneyMoney amortization = totalAmortization(m_startDateEdit->getQDate(), m_endDateEdit->getQDate());
@@ -337,18 +359,18 @@ void KEndingBalanceLoanDlg::next(void)
       m_amortizationTotalEdit->loadText(amortization.formatMoney());
     if(m_interestTotalEdit->text().isEmpty())
       m_interestTotalEdit->loadText(interest.formatMoney());
-      
+
   } else if(currentPage() == m_checkPaymentsPage) {
     m_accountEdit->loadList(static_cast<KMyMoneyUtils::categoryTypeE>(KMyMoneyUtils::asset | KMyMoneyUtils::liability));
     m_categoryEdit->loadList(static_cast<KMyMoneyUtils::categoryTypeE>(KMyMoneyUtils::income | KMyMoneyUtils::expense));
     m_categoryEdit->setEnabled(false);
-    
+
     MyMoneyMoney interest = totalInterest(m_startDateEdit->getQDate(), m_endDateEdit->getQDate());
-    if(interest != m_interestTotalEdit->getMoneyValue()) {
+    if(interest != m_interestTotalEdit->value()) {
       m_categoryEdit->setEnabled(true);
     }
   }
-  
+
   if(!dontLeavePage)
     KEndingBalanceDlgDecl::next();
 
@@ -362,8 +384,8 @@ const MyMoneyTransaction KEndingBalanceLoanDlg::adjustmentTransaction(void) cons
   MyMoneyMoney interest = totalInterest(m_startDateEdit->getQDate(), m_endDateEdit->getQDate());
   MyMoneyMoney amortization = totalAmortization(m_startDateEdit->getQDate(), m_endDateEdit->getQDate());
 
-  if(interest != m_interestTotalEdit->getMoneyValue()
-  || amortization != m_amortizationTotalEdit->getMoneyValue()) {
+  if(interest != m_interestTotalEdit->value()
+  || amortization != m_amortizationTotalEdit->value()) {
     MyMoneySplit sAccount, sAmortization, sInterest;
     int          adjust = 1;
 
@@ -371,11 +393,11 @@ const MyMoneyTransaction KEndingBalanceLoanDlg::adjustmentTransaction(void) cons
       adjust = -1;
 
     // fix sign if asset
-    interest = interest * adjust;
-    amortization = amortization * adjust;
+    interest = interest * MyMoneyMoney(adjust,1);
+    amortization = amortization * MyMoneyMoney(adjust,1);
 
-    sAmortization.setValue((m_amortizationTotalEdit->getMoneyValue() - amortization) * adjust);
-    sInterest.setValue((m_interestTotalEdit->getMoneyValue() - interest) * adjust);
+    sAmortization.setValue((m_amortizationTotalEdit->value() - amortization) * MyMoneyMoney(adjust,1));
+    sInterest.setValue((m_interestTotalEdit->value() - interest) * MyMoneyMoney(adjust,1));
     sAccount.setValue( -(sAmortization.value() + sInterest.value()));
 
     try {
@@ -385,7 +407,7 @@ const MyMoneyTransaction KEndingBalanceLoanDlg::adjustmentTransaction(void) cons
       sAccount.setPayeeId(m_account.payee());
       if(m_categoryEdit->isEnabled())
         sInterest.setAccountId(m_categoryEdit->selectedAccounts()[0]);
-      
+
       sAccount.setMemo(i18n("Adjustment transaction"));
       sAmortization.setMemo(sAccount.memo());
       sInterest.setMemo(sAccount.memo());
@@ -393,14 +415,14 @@ const MyMoneyTransaction KEndingBalanceLoanDlg::adjustmentTransaction(void) cons
       sAccount.setAction(MyMoneySplit::ActionAmortization);
       sAmortization.setAction(MyMoneySplit::ActionAmortization);
       sInterest.setAction(MyMoneySplit::ActionInterest);
-      
+
       t.addSplit(sAccount);
       t.addSplit(sAmortization);
-      if(sInterest.value() != 0)
+      if(!sInterest.value().isZero())
         t.addSplit(sInterest);
-      
+
       t.setPostDate(m_endDateEdit->getQDate());
-      
+
     } catch(MyMoneyException *e) {
       qDebug("Unable to create adjustment transaction for loan reconciliation: %s", e->what().data());
       delete e;
@@ -409,3 +431,15 @@ const MyMoneyTransaction KEndingBalanceLoanDlg::adjustmentTransaction(void) cons
   }
   return t;
 }
+
+void KEndingBalanceLoanDlg::help(void)
+{
+  QString anchor = m_helpAnchor[currentPage()];
+  if(anchor.isEmpty())
+    anchor = QString("details.reconcile.whatis");
+
+  kapp->invokeHelp(anchor);
+}
+
+#include "kendingbalancedlg.moc"
+
