@@ -518,19 +518,25 @@ void KSettingsDlg::configRead()
 
   kconfig->setGroup("List Options");
 
-  m_qcolorTempList = KMyMoneyUtils::defaultListColour();
+  QColor qcolorDefault = KMyMoneyUtils::listColour();
+  m_qcolorTempList = kconfig->readColorEntry("listColor", &qcolorDefault);
   m_kcolorbuttonList->setColor(m_qcolorTempList);
 
-  m_qcolorTempListBG = KMyMoneyUtils::defaultBackgroundColour();
+  qcolorDefault = KMyMoneyUtils::backgroundColour();
+  m_qcolorTempListBG = kconfig->readColorEntry("listBGColor", &qcolorDefault);
   m_kcolorbuttonBack->setColor(m_qcolorTempListBG);
 
-  m_qcolorTempListGrid = KMyMoneyUtils::defaultGridColour();
+  qcolorDefault = KMyMoneyUtils::gridColour();
+  m_qcolorTempListGrid = kconfig->readColorEntry("listGridColor", &qcolorDefault);
   m_kcolorbuttonGrid->setColor(m_qcolorTempListGrid);
 
-  m_qcolorTempRate = QColor(0, 0, 255); // blue is the application default
-  m_qcolorTempRate = kconfig->readColorEntry("listMissingConversionRate", &m_qcolorTempRate);
+  qcolorDefault = KMyMoneyUtils::missingConversionColour();
+  m_qcolorTempRate = kconfig->readColorEntry("listMissingConversionRate", &qcolorDefault);
   m_kcolorbuttonRate->setColor(m_qcolorTempRate);
 
+  m_bTempUseSystemColor = kconfig->readBoolEntry("useSystemColor", true);
+  m_systemColor->setChecked(m_bTempUseSystemColor);
+
   QFont qfontDefault = KMyMoneyUtils::headerFont();
   m_qfontTempHeader = kconfig->readFontEntry("listHeaderFont", &qfontDefault);
   m_kfontchooserHeader->setFont(m_qfontTempHeader);
@@ -593,6 +599,7 @@ void KSettingsDlg::configWrite()
   kconfig->writeEntry("listBGColor", m_kcolorbuttonBack->color());
   kconfig->writeEntry("listGridColor", m_kcolorbuttonGrid->color());
   kconfig->writeEntry("listMissingConversionRate", m_kcolorbuttonRate->color());
+  kconfig->writeEntry("useSystemColor", m_systemColor->isChecked());
   kconfig->writeEntry("listHeaderFont", m_kfontchooserHeader->font());
   kconfig->writeEntry("listCellFont", m_kfontchooserCell->font());
   kconfig->writeEntry("useSystemFont", m_systemFont->isChecked());
@@ -667,8 +674,10 @@ void KSettingsDlg::slotCancel()
   kconfig->writeEntry("listBGColor", m_qcolorTempListBG);
   kconfig->writeEntry("listGridColor", m_qcolorTempListGrid);
   kconfig->writeEntry("listMissingConversionRate", m_qcolorTempRate);
+  kconfig->writeEntry("useSystemColor", m_bTempUseSystemColor);
   kconfig->writeEntry("listHeaderFont", m_qfontTempHeader);
   kconfig->writeEntry("listCellFont", m_qfontTempCell);
+  kconfig->writeEntry("useSystemFont", m_bTempUseSystemFont);
   kconfig->writeEntry("ShowGrid", m_bTempShowGrid);
   kconfig->writeEntry("HideUnusedCategory", m_bTempHideCategory);
   kconfig->writeEntry("StartDate", QDateTime(m_qdateTempStart));
@@ -709,6 +718,7 @@ void KSettingsDlg::slotUser1()
   m_kcolorbuttonBack->setColor(m_qcolorTempListBG);
   m_kcolorbuttonGrid->setColor(m_qcolorTempListGrid);
   m_kcolorbuttonRate->setColor(m_qcolorTempRate);
+  m_systemColor->setChecked(m_bTempUseSystemColor);
   m_kfontchooserHeader->setFont(m_qfontTempHeader);
   m_kfontchooserCell->setFont(m_qfontTempCell);
   m_systemFont->setChecked(m_bTempUseSystemFont);
@@ -815,6 +825,11 @@ void KSettingsDlg::fillHomePageItems(QStringList& list)
   m_homePageList->setColumnWidth(0, w+28);
 }
 
+void KSettingsDlg::slotSystemColorToggled(bool state)
+{
+  m_colorGroupBox->setEnabled(!state);
+}
+
 void KSettingsDlg::slotSystemFontToggled(bool state)
 {
   m_fontTabWidget->setEnabled(!state);
@@ -905,53 +920,57 @@ void KSettingsDlg::setPageColour()
   QVBox *qvboxMainFrame = addVBoxPage( i18n("Colours"), i18n("Colour settings"),
     DesktopIcon("colorscm"));
 
-  QGroupBox* groupBox2 = new QGroupBox( qvboxMainFrame, "groupBox2" );
-  groupBox2->setTitle( i18n( "List Colours" ) );
-  groupBox2->setGeometry( QRect( 20, 10, 430, 340 ) );
-  groupBox2->setColumnLayout(0, Qt::Vertical );
-  groupBox2->layout()->setSpacing( 6 );
-  groupBox2->layout()->setMargin( 11 );
+  m_systemColor = new QCheckBox(qvboxMainFrame, "systemColor");
+  m_systemColor->setText(i18n("Use system colors"));
+  connect(m_systemColor, SIGNAL(toggled(bool)), this, SLOT(slotSystemColorToggled(bool)));
 
-  QVBoxLayout* groupBox2Layout = new QVBoxLayout( groupBox2->layout() );
+  m_colorGroupBox = new QGroupBox( qvboxMainFrame, "m_colorGroupBox" );
+  m_colorGroupBox->setTitle( i18n( "List Colours" ) );
+  m_colorGroupBox->setGeometry( QRect( 20, 10, 430, 340 ) );
+  m_colorGroupBox->setColumnLayout(0, Qt::Vertical );
+  m_colorGroupBox->layout()->setSpacing( 6 );
+  m_colorGroupBox->layout()->setMargin( 11 );
+
+  QVBoxLayout* groupBox2Layout = new QVBoxLayout( m_colorGroupBox->layout() );
   groupBox2Layout->setAlignment( Qt::AlignTop );
 
   QHBoxLayout* layout2 = new QHBoxLayout( 0, 0, 6, "layout2");
 
-  QLabel* textLabel2 = new QLabel( groupBox2, "textLabel2" );
+  QLabel* textLabel2 = new QLabel( m_colorGroupBox, "textLabel2" );
   textLabel2->setText( i18n( "List view colour :" ) );
   layout2->addWidget( textLabel2 );
 
-  m_kcolorbuttonList = new KColorButton( groupBox2, "m_kcolorbuttonList" );
+  m_kcolorbuttonList = new KColorButton( m_colorGroupBox, "m_kcolorbuttonList" );
   layout2->addWidget( m_kcolorbuttonList );
   groupBox2Layout->addLayout( layout2 );
 
   QHBoxLayout* layout3 = new QHBoxLayout( 0, 0, 6, "layout3");
 
-  QLabel* textLabel2_2 = new QLabel( groupBox2, "textLabel2_2" );
+  QLabel* textLabel2_2 = new QLabel( m_colorGroupBox, "textLabel2_2" );
   textLabel2_2->setText( i18n( "List background colour :" ) );
   layout3->addWidget( textLabel2_2 );
 
-  m_kcolorbuttonBack = new KColorButton( groupBox2, "m_kcolorbuttonBack" );
+  m_kcolorbuttonBack = new KColorButton( m_colorGroupBox, "m_kcolorbuttonBack" );
   layout3->addWidget( m_kcolorbuttonBack );
   groupBox2Layout->addLayout( layout3 );
 
   QHBoxLayout* layout4 = new QHBoxLayout( 0, 0, 6, "layout4");
 
-  QLabel* textLabel2_3 = new QLabel( groupBox2, "textLabel2_3" );
+  QLabel* textLabel2_3 = new QLabel( m_colorGroupBox, "textLabel2_3" );
   textLabel2_3->setText( i18n( "List grid colour :" ) );
   layout4->addWidget( textLabel2_3 );
 
-  m_kcolorbuttonGrid = new KColorButton( groupBox2, "m_kcolorbuttonGrid" );
+  m_kcolorbuttonGrid = new KColorButton( m_colorGroupBox, "m_kcolorbuttonGrid" );
   layout4->addWidget( m_kcolorbuttonGrid );
   groupBox2Layout->addLayout( layout4 );
 
   QHBoxLayout* layout5 = new QHBoxLayout( 0, 0, 6, "layout5");
 
-  QLabel* textLabel2_4 = new QLabel( groupBox2, "textLabel2_4" );
+  QLabel* textLabel2_4 = new QLabel( m_colorGroupBox, "textLabel2_4" );
   textLabel2_4->setText( i18n( "Value with missing conversion rate :" ) );
   layout5->addWidget( textLabel2_4 );
 
-  m_kcolorbuttonRate = new KColorButton( groupBox2, "m_kcolorbuttonRate" );
+  m_kcolorbuttonRate = new KColorButton( m_colorGroupBox, "m_kcolorbuttonRate" );
   layout5->addWidget( m_kcolorbuttonRate );
   groupBox2Layout->addLayout( layout5 );
 
