@@ -364,21 +364,21 @@ void KMyMoney2App::slotFileNew()
   QString prevMsg = slotStatusMsg(i18n("Creating new document..."));
 
   slotFileClose();
-  if(myMoneyView->fileOpen())
-    return;
+  if(!myMoneyView->fileOpen()) {
 
-  fileName = KURL();
-  if(myMoneyView->newFile()) {
-    KMessageBox::information(this, QString("<p>") +
-                  i18n("The next dialog allows you to add predefined account/category templates to the new file. Different languages are available to select from. You can skip loading any template  now by selecting <b>Cancel</b> from the next dialog. If you wish to add more templates later, you can restart this operation by selecting <b>File/Import/Account Templates</b>."),
+    fileName = KURL();
+    if(myMoneyView->newFile()) {
+      KMessageBox::information(this, QString("<p>") +
+                    i18n("The next dialog allows you to add predefined account/category templates to the new file. Different languages are available to select from. You can skip loading any template  now by selecting <b>Cancel</b> from the next dialog. If you wish to add more templates later, you can restart this operation by selecting <b>File/Import/Account Templates</b>."),
                   i18n("Load predefined accounts/categories"));
-    slotLoadAccountTemplates();
+      slotLoadAccountTemplates();
+    }
+
+    updateCaption();
+
+    emit fileLoaded(fileName);
   }
-
   slotStatusMsg(prevMsg);
-  updateCaption();
-
-  emit fileLoaded(fileName);
 }
 
 // General open
@@ -581,9 +581,10 @@ void KMyMoney2App::slotFileCloseWindow()
 
   if (myMoneyView->dirty()) {
     int answer = KMessageBox::warningYesNoCancel(this, i18n("The file has been changed, save it ?"));
-    if (answer == KMessageBox::Cancel)
+    if (answer == KMessageBox::Cancel) {
+      slotStatusMsg(prevMsg);
       return;
-    else if (answer == KMessageBox::Yes)
+    } else if (answer == KMessageBox::Yes)
       slotFileSave();
   }
 
@@ -732,15 +733,12 @@ void KMyMoney2App::progressCallback(int current, int total, const QString& msg)
 
 void KMyMoney2App::slotFileViewPersonal()
 {
-  QString prevMsg = slotStatusMsg(i18n("Viewing personal data..."));
-
-
   if ( !myMoneyView->fileOpen() ) {
-
     KMessageBox::information(this, i18n("No KMyMoney file open"));
     return;
   }
 
+  QString prevMsg = slotStatusMsg(i18n("Viewing personal data..."));
   myMoneyView->viewPersonal();
   updateCaption();
 
@@ -1103,8 +1101,8 @@ void KMyMoney2App::slotStatementImport()
   {
     // re-enable all standard widgets
     setEnabled(true);
-    slotStatusMsg(prevMsg);
   }
+  slotStatusMsg(prevMsg);
 }
 
 bool KMyMoney2App::slotStatementImport(const QString& url)
@@ -1512,6 +1510,7 @@ void KMyMoney2App::slotSetViewSpecificActions(int view)
   filePrint->setEnabled(false);
   switch(view) {
     case KMyMoneyView::ReportsView:
+    case KMyMoneyView::HomeView:
       filePrint->setEnabled(true);
       break;
     default:
@@ -1962,6 +1961,8 @@ void KMyMoney2App::webConnect(const QString& url, const QCString& asn_id)
     if ( it_plugin == m_importerPlugins.end() )
       if ( MyMoneyStatement::isStatementFile( url ) )
         slotStatementImport(url);
+
+    slotStatusMsg(prevMsg);
   }
 }
 
