@@ -158,7 +158,8 @@ void MyMoneyFile::modifyTransaction(const MyMoneyTransaction& transaction)
   // into amortization splits
   if(loanAccountAffected) {
     tCopy = transaction;
-    for(it_s = tCopy.splits().begin(); it_s != tCopy.splits().end(); ++it_s) {
+    QValueList<MyMoneySplit> list = transaction.splits();
+    for(it_s = list.begin(); it_s != list.end(); ++it_s) {
       if((*it_s).action() == MyMoneySplit::ActionTransfer) {
         MyMoneyAccount acc = MyMoneyFile::account((*it_s).accountId());
 
@@ -689,7 +690,8 @@ void MyMoneyFile::addTransaction(MyMoneyTransaction& transaction)
   // change transfer splits between asset/liability and loan accounts
   // into amortization splits
   if(loanAccountAffected) {
-    for(it_s = transaction.splits().begin(); it_s != transaction.splits().end(); ++it_s) {
+    QValueList<MyMoneySplit> list = transaction.splits();
+    for(it_s = list.begin(); it_s != list.end(); ++it_s) {
       if((*it_s).action() == MyMoneySplit::ActionTransfer) {
         MyMoneyAccount acc = MyMoneyFile::account((*it_s).accountId());
 
@@ -1054,7 +1056,7 @@ const MyMoneyMoney MyMoneyFile::accountValue(const QCString& id, const QDate& da
       e->what().data(), e->file().data(), e->line());
     delete e;
   }
-  return result;
+  return result.convert(baseCurrency().smallestAccountFraction());
 }
 
 const MyMoneyMoney MyMoneyFile::totalValue(const QCString& id, const QDate& date) const
