@@ -207,6 +207,12 @@ QDate MyMoneySchedule::nextPayment(const QDate& refDate) const
         return QDate();
 
       return paymentDate;
+
+    } else {
+      // if the first payment date is past the given ref date,
+      // then that's what we're looking for
+      if(paymentDate > refDate)
+        return paymentDate;
     }
   }
 
@@ -655,8 +661,14 @@ bool MyMoneySchedule::isOverdue() const
 
 bool MyMoneySchedule::isFinished() const
 {
-  if (m_endDate.isValid() && m_lastPayment >= m_endDate)
-    return true;
+  if (m_endDate.isValid()) {
+    if(m_lastPayment >= m_endDate)
+      return true;
+
+    QDate next = nextPayment(m_lastPayment);
+    if(!next.isValid() || next > m_endDate)
+      return true;
+  }
 
   // Check to see if its a once off payment
   if (m_occurence == MyMoneySchedule::OCCUR_ONCE && m_lastPayment.isValid())
