@@ -48,7 +48,8 @@ MyMoneyTransaction::~MyMoneyTransaction()
 bool MyMoneyTransaction::operator == (const MyMoneyTransaction& right) const
 {
   return ((m_id == right.m_id) &&
-      (m_memo == right.m_memo) &&
+      (m_commodity == right.m_commodity) &&
+      ((m_memo.length() == 0 && right.m_memo.length() == 0) || (m_memo == right.m_memo)) &&
       (m_splits == right.m_splits) &&
       (m_entryDate == right.m_entryDate) &&
       (m_postDate == right.m_postDate) );
@@ -102,7 +103,7 @@ void MyMoneyTransaction::modifySplit(MyMoneySplit& split)
   QValueList<MyMoneySplit>::Iterator self = m_splits.end();
   QValueList<MyMoneySplit>::Iterator dup = self;
   bool duplicateAccount = false;
-  
+
   for(it = m_splits.begin(); it != m_splits.end(); ++it) {
     if(split.id() == (*it).id()) {
       self = it;
@@ -132,7 +133,7 @@ void MyMoneyTransaction::modifySplit(MyMoneySplit& split)
       return;
     }
   }
-  throw new MYMONEYEXCEPTION("Invalid split id '" + split.id() + "'");
+  throw new MYMONEYEXCEPTION(QString("Invalid split id '%1'").arg(split.id()));
 }
 
 void MyMoneyTransaction::removeSplit(const MyMoneySplit& split)
@@ -146,7 +147,7 @@ void MyMoneyTransaction::removeSplit(const MyMoneySplit& split)
     }
   }
   if(it == m_splits.end())
-    throw new MYMONEYEXCEPTION("Invalid split id '" + split.id() + "'");
+    throw new MYMONEYEXCEPTION(QString("Invalid split id '%1'").arg(split.id()));
 }
 
 void MyMoneyTransaction::removeSplits(void)
@@ -162,7 +163,7 @@ const MyMoneySplit& MyMoneyTransaction::splitByPayee(const QCString& payeeId) co
     if((*it).payeeId() == payeeId)
       return *it;
   }
-  throw new MYMONEYEXCEPTION(QString("Split not found for payee") + QString(payeeId));
+  throw new MYMONEYEXCEPTION(QString("Split not found for payee '%1'").arg(QString(payeeId)));
 }
 
 const MyMoneySplit& MyMoneyTransaction::splitByAccount(const QCString& accountId, const bool match) const
@@ -175,7 +176,20 @@ const MyMoneySplit& MyMoneyTransaction::splitByAccount(const QCString& accountId
     if(match == false && (*it).accountId() != accountId)
       return *it;
   }
-  throw new MYMONEYEXCEPTION(QString("Split not found for account") + QString(accountId));
+  throw new MYMONEYEXCEPTION(QString("Split not found for account %1%2").arg(match?"":"!").arg(QString(accountId)));
+}
+
+const MyMoneySplit& MyMoneyTransaction::splitByAccount(const QCStringList& accountIds, const bool match) const
+{
+  QValueList<MyMoneySplit>::ConstIterator it;
+
+  for(it = m_splits.begin(); it != m_splits.end(); ++it) {
+    if(match == true && accountIds.contains((*it).accountId()) )
+      return *it;
+    if(match == false && !accountIds.contains((*it).accountId()))
+      return *it;
+  }
+  throw new MYMONEYEXCEPTION(QString("Split not found for account  %1%1...%2").arg(match?"":"!").arg(accountIds.front(),accountIds.back()));
 }
 
 const MyMoneySplit& MyMoneyTransaction::splitById(const QCString& splitId) const
@@ -186,7 +200,7 @@ const MyMoneySplit& MyMoneyTransaction::splitById(const QCString& splitId) const
     if((*it).id() == splitId)
       return *it;
   }
-  throw new MYMONEYEXCEPTION(QString("Split not found for id ") + QString(splitId));
+  throw new MYMONEYEXCEPTION(QString("Split not found for id '%1'").arg(QString(splitId)));
 }
 
 const QCString MyMoneyTransaction::nextSplitID()
@@ -194,7 +208,13 @@ const QCString MyMoneyTransaction::nextSplitID()
   QCString id;
   id = "S" + id.setNum(m_nextSplitID++).rightJustify(SPLIT_ID_SIZE, '0');
   return id;
+}
 
+const QCString MyMoneyTransaction::firstSplitID()
+{
+  QCString id;
+  id = "S" + id.setNum(1).rightJustify(SPLIT_ID_SIZE, '0');
+  return id;
 }
 
 const MyMoneyMoney MyMoneyTransaction::splitSum(void) const
@@ -226,3 +246,58 @@ const bool MyMoneyTransaction::isLoanPayment(void) const
   }
   return false;
 }
+
+const unsigned long MyMoneyTransaction::hash(const QString& txt) const
+{
+  unsigned long   h = 0,
+                  g;
+
+  for(unsigned i=0; i < txt.length(); ++i) {
+    h = (h << 4) + txt[i].latin1();
+    if( (g = (h & 0xf0000000)) ) {
+      h = h ^ (g >> 24);
+      h = h ^ g;
+    }
+  }
+  return h;
+}
+
+const bool MyMoneyTransaction::isDuplicate(const MyMoneyTransaction& r) const
+{
+  bool rc = true;
+  if(splitCount() != r.splitCount()) {
+    rc = false;
+  } else {
+    if(abs(m_postDate.daysTo(r.postDate())) > 3) {
+      rc = false;
+    } else {
+      unsigned long accHash[2];
+      unsigned long valHash[2];
+      unsigned long numHash[2];
+      for(int i = 0; i < 2; ++i)
+        accHash[i] = valHash[i] = numHash[i] = 0;
+
+      QValueList<MyMoneySplit>::ConstIterator it;
+      for(it = splits().begin(); it != splits().end(); ++it) {
+        accHash[0] += hash((*it).accountId());
+        valHash[0] += hash((*it).value().formatMoney("", 4));
+        numHash[0] += hash((*it).number());
+      }
+      for(it = r.splits().begin(); it != r.splits().end(); ++it) {
+        accHash[1] += hash((*it).accountId());
+        valHash[1] += hash((*it).value().formatMoney("", 4));
+        numHash[1] += hash((*it).number());
+      }
+
+      if(accHash[0] != accHash[1]
+      || valHash[0] != valHash[1]
+      || numHash[0] != numHash[1]
+      ) {
+        rc = false;
+      }
+    }
+  }
+
+  return rc;
+}
+
