@@ -23,10 +23,14 @@
 #ifndef _MYMONEYUTILS_H_
 #define _MYMONEYUTILS_H_
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <qstring.h>
 #include <qcstring.h>
 #include <qvaluelist.h>
-
+#include <kmymoney/export.h>
 #if 0
 
 //Includes for STL support below
@@ -64,7 +68,34 @@ public:
 
   //static function to add the correct file extension at the end of the file name
   static QString getFileExtension(QString strFileName);
-  
+
+};
+
+class KMYMONEY_EXPORT MyMoneyTracer
+{
+public:
+  MyMoneyTracer(const char* prettyName);
+#define MYMONEYTRACER(a) MyMoneyTracer a(__PRETTY_FUNCTION__)
+
+  MyMoneyTracer(const QString& className, const QString& methodName);
+  ~MyMoneyTracer();
+
+  /**
+    * This method allows to trace a printf like formatted text
+    *
+    * @param format format mask
+    */
+  void printf(const char *format, ...) const __attribute__ ((format (__printf__, 2, 3)));
+
+  static void off(void);
+  static void on(void);
+
+private:
+  QString m_className;
+  QString m_memberName;
+
+  static int m_indentLevel;
+  static int m_onoff;
 };
 
 #ifdef _CHECK_MEMORY
@@ -94,7 +125,7 @@ typedef QMap<void *, _CheckMemoryEntry> CheckMemoryTable;
 
 typedef void _CheckMemoryOutFunc(const char *);
 
-class _CheckMemory {
+class KMYMONEY_EXPORT _CheckMemory {
  public:
   _CheckMemory();
   _CheckMemory(_CheckMemoryOutFunc *out);
@@ -108,7 +139,7 @@ class _CheckMemory {
   int TableCount(void);
 
  private:
-  void Output(const char *fmt,...);
+  void Output(const char *fmt,...) __attribute__ ((format (__printf__, 2, 3)));
 
   CheckMemoryTable table;
   _CheckMemoryOutFunc *outfunc;
@@ -119,17 +150,17 @@ class _CheckMemory {
   friend void operator delete [] (void *p) throw();
 };
 
-void * operator new(size_t s,const char *file,int line) throw(); // Normal new operator
-void * operator new [] (size_t s,const char *file,int line) throw(); // Array new operator
-void operator delete(void *p) throw();
-void operator delete [] (void *p) throw();
+KMYMONEY_EXPORT void * operator new(size_t s,const char *file,int line) throw(); // Normal new operator
+KMYMONEY_EXPORT void * operator new [] (size_t s,const char *file,int line) throw(); // Array new operator
+KMYMONEY_EXPORT void operator delete(void *p) throw();
+KMYMONEY_EXPORT void operator delete [] (void *p) throw();
 
 #define new new(__FILE__,__LINE__)
 
-extern _CheckMemory chkmem;
+KMYMONEY_EXPORT extern _CheckMemory chkmem;
 
-void _CheckMemory_Init(_CheckMemoryOutFunc *out);
-void _CheckMemory_End();
+KMYMONEY_EXPORT void _CheckMemory_Init(_CheckMemoryOutFunc *out);
+KMYMONEY_EXPORT void _CheckMemory_End();
 #define _CheckMemory_Leak(freeall) chkmem.CheckMemoryLeak(freeall)
 #define _CheckMemory_FreeAll() chkmem.FreeAll()
 
