@@ -79,7 +79,7 @@ public:
   virtual void setUserEmail(const QString& val) = 0;
 
   // methods provided by MyMoneyKeyValueContainer
-  virtual void setValue(const QCString& key, const QString& key) = 0;
+  virtual void setValue(const QCString& key, const QString& value) = 0;
   virtual const QString value(const QCString& key) const = 0;
   virtual void deletePair(const QCString& key) = 0;
 
