@@ -878,13 +878,14 @@ public:
 
   /**
     * This method retrieves a price from the price list
+    * If @p date is inValid, QDate::currentDate() is assumed.
     */
-  const MyMoneyPrice price(const QCString& fromId, const QCString& toId, const QDate& date, const bool exactDate) const;
+  MyMoneyPrice price(const QCString& fromId, const QCString& toId, const QDate& date, const bool exactDate) const;
 
   /**
     * This method returns a list of all price entries.
     */
-  const MyMoneyPriceList priceList(void) const;
+  const MyMoneyPriceList& priceList(void) const;
 
 private:
 
