@@ -69,7 +69,7 @@ void MyMoneyStorageXML::readFile(QIODevice* pDevice, IMyMoneySerialize* storage)
 
   m_doc = new QDomDocument;
   Q_CHECK_PTR(m_doc);
-  if(m_doc->setContent(pDevice, FALSE))
+  if(m_doc->setContent(pDevice, false))
   {
     QDomElement rootElement = m_doc->documentElement();
     if(!rootElement.isNull())
