@@ -817,7 +817,7 @@ QString PivotTable::renderCSV( void ) const
 
         innergroupdata += "\"" + QString().fill(' ',rowname.hierarchyDepth() - 1) + rowname.name();
 
-        if (m_config_f.isConvertCurrency() || !rowname.isForiegnCurrency() )
+        if (!m_config_f.isConvertCurrency() && rowname.isForiegnCurrency() )
           innergroupdata += QString(" (%1)").arg(rowname.currencyId());
 
         innergroupdata += "\"";
@@ -854,7 +854,7 @@ QString PivotTable::renderCSV( void ) const
         ReportAccount rowname = (*it_innergroup).begin().key();
 
         result += "\"" + QString().fill(' ',rowname.hierarchyDepth() - 1) + rowname.name();
-        if (m_config_f.isConvertCurrency() || !rowname.isForiegnCurrency() )
+        if (!m_config_f.isConvertCurrency() && rowname.isForiegnCurrency() )
           result += QString(" (%1)").arg(rowname.currencyId());
         result += "\"";
 
