@@ -74,11 +74,8 @@ KAccountsView::KAccountsView(QWidget *parent, const char *name, bool bInstitutio
   accountListView->setColumnAlignment(3, Qt::AlignRight);
 
   accountListView->setResizeMode(QListView::AllColumns);
-
   accountListView->header()->setResizeEnabled(true);
 
-  accountListView->header()->setFont(KMyMoneyUtils::headerFont());
-
   if(!m_bViewNormalAccountsView) {
     // select the type the user viewed last (list or icon) but only
     // for the accounts view
@@ -443,8 +440,6 @@ void KAccountsView::fillAccountMap(void)
 
 void KAccountsView::refresh(const QCString& selectAccount)
 {
-  accountListView->header()->setFont(KMyMoneyUtils::headerFont());
-
   KConfig *config = KGlobal::config();
   config->setGroup("List Options");
   m_hideCategory = config->readBoolEntry("HideUnusedCategory", false);
@@ -471,6 +466,10 @@ void KAccountsView::refresh(const QCString& selectAccount)
   // turn off updates to avoid flickering during reload
   accountListView->setUpdatesEnabled(false);
 
+  // set font according configuration
+  accountListView->header()->setFont(KMyMoneyUtils::headerFont());
+  accountListView->setFont(KMyMoneyUtils::cellFont());
+
   // Disable the note about hidden categories
   m_hiddenCategories->hide();
 
@@ -584,6 +583,7 @@ void KAccountsView::refresh(const QCString& selectAccount)
 
   } else {       // Show new 'advanced' view
     accountListView->header()->setLabel(0, i18n("Account"));
+
     // Do all 5 account roots
     try {
       // Asset
