@@ -159,9 +159,10 @@ KLedgerViewCheckings::~KLedgerViewCheckings()
 
 void KLedgerViewCheckings::refreshView(void)
 {
-  if(m_inReconciliation)
+  if(m_inReconciliation) {
     KLedgerView::refreshView(m_transactionCheckBox->isChecked());
-  else
+    fillReconcileData();
+  } else
     KLedgerView::refreshView();
 
   QDate date;
@@ -1534,7 +1535,7 @@ void KLedgerViewCheckings::slotConfigureMoreMenu(void)
         dest = acc.name();
       } catch(MyMoneyException *e) {
         delete e;
-        dest = "opposite account";
+        dest = i18n("opposite account");
       }
       m_moreMenu->changeItem(splitEditId, i18n("Goto '%1'").arg(dest));
       m_moreMenu->connectItem(splitEditId, this, SLOT(slotGotoOtherSideOfTransfer()));
