@@ -423,16 +423,11 @@ void KPayeesView::slotDeletePayee()
 
 void KPayeesView::readConfig(void)
 {
-  QFont font = KMyMoneyUtils::cellFont();
-  m_transactionView->setFont(font);
+  m_transactionView->setFont(KMyMoneyUtils::cellFont());
+  m_payeesList->setFont(KMyMoneyUtils::cellFont());
 
-  font = KMyMoneyUtils::headerFont();
-  QFontMetrics fm( font );
-  int height = fm.lineSpacing()+6;
-
-  m_transactionView->header()->setMinimumHeight(height);
-  m_transactionView->header()->setMaximumHeight(height);
-  m_transactionView->header()->setFont(font);
+  m_transactionView->header()->setFont(KMyMoneyUtils::headerFont());
+  m_payeesList->header()->setFont(KMyMoneyUtils::headerFont());
 
   KConfig* kconfig = KGlobal::config();
   kconfig->setGroup("General Options");
