@@ -31,16 +31,19 @@
 #include <qlabel.h>
 #include <qtable.h>
 #include <qbitarray.h>
+#include <qtoolbutton.h>
 
 // ----------------------------------------------------------------------------
 // KDE Includes
 
+#include <ktoolbarbutton.h>
+
 // ----------------------------------------------------------------------------
 // Project Includes
 
 class QVBoxLayout;
-class QHBoxLayout; 
-class QGridLayout; 
+class QHBoxLayout;
+class QGridLayout;
 class KPushButton;
 class QFrame;
 class QTable;
@@ -61,24 +64,28 @@ public:
   void paintFocus(QPainter *p, const QRect &cr);
   QWidget* createEditor(int row, int col, bool initFromCell) const;
 
-  void setEditable(int row, int col, bool editable = true);
+  void setEditable(const int row, const int col, const bool editable = true);
+
   void clearEditable(void);
 
   bool eventFilter( QObject * o, QEvent * );
 
   QSize sizeHint() const;
-  
+
+  void adjustColumn(const int col, const int minWidth = 0);
+
+  void setNumRows(const int r, const int rowHeight);
+
 public slots:
   virtual void setNumCols(int c);
-  virtual void setNumRows(int r);
-  
+
 protected:
   bool focusNextPrevChild(bool next);
 
 private:
   void resizeEditable(int r, int c);
   QSize tableSize(void) const;
-  
+
 private:
   QBitArray m_editable;
   KLedgerView*  m_view;
@@ -123,32 +130,34 @@ private:
 };
 
 class kMyMoneyTransactionForm : public QWidget
-{ 
+{
   Q_OBJECT
 
 public:
-  kMyMoneyTransactionForm( KLedgerView* parent = 0, const char* name = 0, WFlags fl = 0, const int rows = 4, const int cols = 4 );
+  kMyMoneyTransactionForm( KLedgerView* parent = 0, const char* name = 0, WFlags fl = 0, const int rows = 4, const int cols = 4 , const int rowHeight = 25);
   ~kMyMoneyTransactionForm();
 
   void addTab(QTab *tab) { m_tabBar->addTab(tab); };
   kMyMoneyTransactionFormTable* table(void) { return formTable; };
   QTabBar* tabBar(void) { return m_tabBar; };
-  KPushButton* newButton(void) const { return buttonNew; };
-  KPushButton* editButton(void) const { return buttonEdit; };
-  KPushButton* enterButton(void) const { return buttonEnter; };
-  KPushButton* cancelButton(void) const { return buttonCancel; };
-  KPushButton* moreButton(void) const { return buttonMore; };
+  KToolBarButton* newButton(void) const { return buttonNew; };
+  KToolBarButton* editButton(void) const { return buttonEdit; };
+  KToolBarButton* enterButton(void) const { return buttonEnter; };
+  KToolBarButton* cancelButton(void) const { return buttonCancel; };
+  KToolBarButton* moreButton(void) const { return buttonMore; };
+  KToolBarButton* accountButton(void) const { return buttonAccount; };
 
 protected:
   QTabBar* m_tabBar;
   QFrame* formFrame;
   kMyMoneyTransactionFormTable* formTable;
-
-  KPushButton* buttonNew;
-  KPushButton* buttonEdit;
-  KPushButton* buttonEnter;
-  KPushButton* buttonCancel;
-  KPushButton* buttonMore;
+  KToolBar* m_toolbar;
+  KToolBarButton* buttonNew;
+  KToolBarButton* buttonEdit;
+  KToolBarButton* buttonEnter;
+  KToolBarButton* buttonCancel;
+  KToolBarButton* buttonMore;
+  KToolBarButton* buttonAccount;
 
   KLedgerView*  m_view;
 
